Attribute VB_Name = "Mdulo1"
'
'  ************************************************
'                funcin "poros"
'  ************************************************
'
' d- dimetro equivalente (cm)
' d1- esfericidad
' d3- densidad del material(g/cm3)
' e1- densidad del fluido (g/cm3)
' e2- viscosidad del fluido (poise)
' p1- porosidad del medio
' u1- velocidad del agua durante el lavado (cm/min)
'
' algoritmo obtenido del artculo "Predicting the
' Expansion Behavior of Filter Media". A.H. Darmarajah
' y John L. Cleasby. Journal AWWA, vol 78(12),
' dic 1986
Dim d, d1, d3, e1, e2, p1, u1, r1, r2, r3, g As Double
Dim s, b2, u2, p3 As Double

' calcula nmero de Reynolds
' modificado de Blake (Re1)
Private Function Fnc1(X) As Single
      Fnc1 = u2 * e1 / (s * e2 * (1 - X))
End Function

' calcula el nmero adimensional A1
Private Function Fnc2(X) As Single
      Fnc2 = X ^ 3 * (d3 - e1) * e1 * g / (1 - X) ^ 2 / s ^ 3 / e2 ^ 2
End Function

Private Function Fnc3(X) As Single
      Fnc3 = Log10(Fnc2(X)) - 0.56543 - 1.09348 * Log10(Fnc1(X)) - 0.17979 * Log10(Fnc1(X)) ^ 2 + 0.00392 * Log10(Fnc1(X)) ^ 4 + 1.5 * Log10(d1) ^ 2
End Function

Private Function Fnc4(X) As Single
      Fnc4 = Fnc2(X) - 3 * Fnc1(X)
End Function

Static Function Log10(X)
    Log10 = Log(X) / Log(10#)
End Function

Public Function Poros(z1, z2, z3, z4, z5, z6, z7) As Single
      d = z1
      d1 = z2
      d3 = z3
      e1 = z4
      e2 = z5
      p1 = z6
      u1 = z7
      
      r1 = 0.35    ' en el programa original es 0.40
      r2 = 1
      g = 981
      r3 = 0.0001 ' en el programa original es 0.005
      s = 6 / (d1 * d)
      u2 = u1
      x1 = r1
      x2 = r2
      x3 = (x1 + x2) / 2
SIGUE:
      If Abs(x3 - x1) <= r3 Then GoTo SALE
      If Fnc3(x1) * Fnc3(x3) > 0 Then x1 = x3 Else x2 = x3
      x3 = (x1 + x2) / 2
      GoTo SIGUE
SALE:
      If Fnc1(x3) >= 0.2 Then GoTo SALE1
      x1 = r1
      x2 = r2
      x3 = (x1 + x2) / 2
SIGUE1:
      If Abs(x3 - x1) <= r3 Then GoTo SALE1
      If Fnc4(x1) * Fnc4(x3) > 0 Then x1 = x3 Else x2 = x3
      x3 = (x1 + x2) / 2
      GoTo SIGUE1
SALE1:
      If x3 < p1 Then x3 = p1
      p3 = (1 - p1) / (1 - x3)
      Poros = x3  ' x3 es la porosidad del lecho
                  ' expandido y p3 es el % de exp.
End Function

' **********************************************

